pub fn py_change_tofrunconfig(cfg: &PyTofRunConfig) -> PyResult<PyTofCommand>Expand description
Change the run config part of the config file
pub fn py_change_tofrunconfig(cfg: &PyTofRunConfig) -> PyResult<PyTofCommand>Change the run config part of the config file